pub enum Status {
Editing {
edit: String,
previous: Option<usize>,
},
Idle,
Exiting,
}Expand description
The current status of application
Variants
Editing
Editing state
edit stores the buffer value for the new task
previous tells if we are editing a task or creating new one
Idle
Idle state
Exiting
Exiting state
This is to avoid abrupt closure and ask before exit